pub enum MetaKey {
BinaryOp(BinaryOp),
UnaryOp(UnaryOp),
Call,
IndexMut,
Named(KString),
Test(KString),
PreTest,
PostTest,
Main,
Type,
Base,
}Expand description
The key type used by MetaMaps
Variants
BinaryOp(BinaryOp)
A binary operation
e.g. @+, @==
UnaryOp(UnaryOp)
A unary operation
e.g. @not
Call
Function call - @call
Defines the behaviour when performing a function call on the object.
IndexMut
@index_mut
Defines how an object should behave in mutable indexing operations.
Named(KString)
A named key
e.g. @meta my_named_key
Named entries are used in KMaps, so that shared named items can be
made available without them being inserted into the map’s contents.
Test(KString)
A test function
e.g. @test my_test
PreTest
@pre_test
Used to define a function that will be run before each @test.
PostTest
@post_test
Used to define a function that will be run after each @test.
Main
@main
Used to define a function that will be run when a module is first imported.
Type
@type
Provides a KString that declares the value’s type.
Base
@base
Defines a base map to be used as fallback for accesses when a key isn’t found.