DisplayContext

Struct DisplayContext 

pub struct DisplayContext<'a> { /* private fields */ }
A helper for converting Koto values to strings

Implementations

Source

impl<'a> DisplayContext<'a>

pub fn with_vm(vm: &'a KotoVm) -> Self

Makes a display context with the given VM

pub fn with_vm_and_capacity(vm: &'a KotoVm, capacity: usize) -> Self

Makes a display context with the given VM and reserved capacity

pub fn enable_debug(self) -> Self

Enables the debug flag on the display context

pub fn result(self) -> String

Returns the resulting string and consumes the context

pub fn append<'b>(&mut self, s: impl Into<StringBuilderAppend<'b>>)

Appends to the end of the string

pub fn vm(&self) -> &Option<&'a KotoVm>

Returns a reference to the context’s VM

pub fn debug_enabled(&self) -> bool

True if the resulting string will be used in a debug context

This is true when a debug expression is being used, or when using the ? representation in a formatted string.

pub fn is_contained(&self) -> bool

Returns true if the value that’s being displayed is in a container

pub fn is_in_parents(&self, id: Address) -> bool

Returns true if the given ID is present in the parent container list

pub fn push_container(&mut self, id: Address)

Adds the given ID to the parents list

Containers should call this before displaying their contained values.

pub fn pop_container(&mut self)

Pops the previously added parent ID

Containers should call this after displaying their contained values.