pub struct DisplayContext<'a> { /* private fields */ }Expand description
A helper for converting Koto values to strings
Implementations
Sourceimpl<'a> DisplayContext<'a>
impl<'a> DisplayContext<'a>
Sourcepub fn with_vm_and_capacity(vm: &'a KotoVm, capacity: usize) -> Self
pub fn with_vm_and_capacity(vm: &'a KotoVm, capacity: usize) -> Self
Makes a display context with the given VM and reserved capacity
Sourcepub fn enable_debug(self) -> Self
pub fn enable_debug(self) -> Self
Enables the debug flag on the display context
Sourcepub fn append<'b>(&mut self, s: impl Into<StringBuilderAppend<'b>>)
pub fn append<'b>(&mut self, s: impl Into<StringBuilderAppend<'b>>)
Appends to the end of the string
Sourcepub fn debug_enabled(&self) -> bool
pub fn debug_enabled(&self) -> bool
True if the resulting string will be used in a debug context
This is true when a debug expression is being used, or when using the ? representation
in a formatted string.
Sourcepub fn is_contained(&self) -> bool
pub fn is_contained(&self) -> bool
Returns true if the value that’s being displayed is in a container
Sourcepub fn is_in_parents(&self, id: Address) -> bool
pub fn is_in_parents(&self, id: Address) -> bool
Returns true if the given ID is present in the parent container list
Sourcepub fn push_container(&mut self, id: Address)
pub fn push_container(&mut self, id: Address)
Adds the given ID to the parents list
Containers should call this before displaying their contained values.
Sourcepub fn pop_container(&mut self)
pub fn pop_container(&mut self)
Pops the previously added parent ID
Containers should call this after displaying their contained values.